FrameGrabberInterfacesRefactor4 {#master}
-------------------------------

## Libraries

### `dev`

* Properly mark the `yarp/dev/FrameGrabberControl2.h` header file as deprecated
  (it should have been deprecated in YARP 3.0)
* The `yarp/dev/FrameGrabberInterfaces.h` header file was deprecated.
  All interfaces were moved in the corresponding header.
